@@ -15,7 +15,7 @@ use core_graphics::font::{CGFont, CGGlyph};
 use core_graphics::geometry::{CGPoint, CGRect, CGSize};
 use core_text::font::{
     cascade_list_for_languages as ct_cascade_list_for_languages,
-    new_from_descriptor as ct_new_from_descriptor, CTFont,
+    new_from_descriptor as ct_new_from_descriptor, new_from_name, CTFont,
 };
 use core_text::font_collection::create_for_family;
 use core_text::font_collection::get_family_names as ct_get_family_names;
@@ -75,41 +75,28 @@ impl Descriptor {
         let cg_font = ct_font.copy_to_CGFont();
 
         let fallbacks = if load_fallbacks {
-            descriptors_for_family("Menlo")
+            // TODO fixme, hardcoded en for english.
+            let mut fallbacks = cascade_list_for_languages(&ct_font, &["en".to_owned()])
                 .into_iter()
-                .find(|d| d.font_name == "Menlo-Regular")
-                .map(|descriptor| {
-                    let menlo = ct_new_from_descriptor(&descriptor.ct_descriptor, size);
+                .filter(|desc| !desc.font_path.as_os_str().is_empty())
+                .map(|desc| desc.to_font(size, false))
+                .collect::<Vec<_>>();
 
-                    // TODO fixme, hardcoded en for english.
-                    let mut fallbacks = cascade_list_for_languages(&menlo, &["en".to_owned()])
-                        .into_iter()
-                        .filter(|desc| !desc.font_path.as_os_str().is_empty())
-                        .map(|desc| desc.to_font(size, false))
-                        .collect::<Vec<_>>();
-
-                    // TODO, we can't use apple's proposed
-                    // .Apple Symbol Fallback (filtered out below),
-                    // but not having these makes us not able to render
-                    // many chars. We add the symbols back in.
-                    // Investigate if we can actually use the .-prefixed
-                    // fallbacks somehow.
-                    if let Some(descriptor) =
-                        descriptors_for_family("Apple Symbols").into_iter().next()
-                    {
-                        fallbacks.push(descriptor.to_font(size, false))
-                    };
-
-                    // Include Menlo in the fallback list as well.
-                    fallbacks.insert(0, Font {
-                        cg_font: menlo.copy_to_CGFont(),
-                        ct_font: menlo,
-                        fallbacks: Vec::new(),
-                    });
-
-                    fallbacks
+            // TODO, we can't use apple's proposed
+            // .Apple Symbol Fallback (filtered out below),
+            // but not having these makes us not able to render
+            // many chars. We add the symbols back in.
+            // Investigate if we can actually use the .-prefixed
+            // fallbacks somehow.
+            if let Ok(apple_symbols) = new_from_name("Apple Symbols", size) {
+                fallbacks.push(Font {
+                    cg_font: apple_symbols.copy_to_CGFont(),
+                    ct_font: apple_symbols,
+                    fallbacks: Vec::new(),
                 })
-                .unwrap_or_else(Vec::new)
+            };
+
+            fallbacks
         } else {
             Vec::new()
         };
@@ -181,6 +168,10 @@ impl crate::Rasterize for Rasterizer {
         }
     }
 
+    fn kerning(&mut self, left: GlyphKey, right: GlyphKey) -> (f32, f32) {
+        (0., 0.)
+    }
+
     fn update_dpr(&mut self, device_pixel_ratio: f32) {
         self.device_pixel_ratio = device_pixel_ratio;
     }
@@ -288,8 +279,7 @@ pub fn get_family_names() -> Vec<String> {
 fn cascade_list_for_languages(ct_font: &CTFont, languages: &[String]) -> Vec<Descriptor> {
     // Convert language type &Vec<String> -> CFArray.
     let langarr: CFArray<CFString> = {
-        let tmp: Vec<CFString> =
-            languages.iter().map(|language| CFString::new(&language)).collect();
+        let tmp: Vec<CFString> = languages.iter().map(|language| CFString::new(language)).collect();
         CFArray::from_CFTypes(&tmp)
     };
 
@@ -410,6 +400,7 @@ impl Font {
                 height: 0,
                 top: 0,
                 left: 0,
+                advance: (0, 0),
                 buffer: BitmapBuffer::Rgb(Vec::new()),
             };
         }
@@ -475,6 +466,7 @@ impl Font {
             top: (bounds.size.height + bounds.origin.y).ceil() as i32,
             width: rasterized_width as i32,
             height: rasterized_height as i32,
+            advance: (0, 0),
             buffer,
         }
     }
